Products  What's New  Explore SAP  Products  What's New  Explore SAP
  * [Home](https://help.sap.com/docs/)
  * [SAP LeanIX](https://help.sap.com/docs/leanix)
  * …
  * [Single Sign-On (SSO)](https://help.sap.com/docs/leanix/ea/single-sign-on-sso)
  * Migration to the Self-Service SSO Configuration
